@@ -1,20 +1,17 @@
 ## Copyright (C) 2009 VZLU Prague, a.s., Czech Republic
 ##
-## Author: Jaroslav Hajek <highegg@gmail.com>
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with this program; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn{Function File} {[@var{q}, @var{r}, @var{z}] =} cod (@var{a})
@@ -36,11 +33,13 @@
 ## If a second argument of '0' is given, an economy-sized factorization is returned
 ## so that @var{r} is K-by-K.
 ##
-## NOTE: This is currently implemented by double QR factorization plus some
+## @emph{NOTE}: This is currently implemented by double QR factorization plus some
 ## tricky manipulations, and is not as efficient as using xRZTZF from LAPACK.
 ## @seealso{qr}
 ## @end deftypefn
 
+## Author: Jaroslav Hajek <highegg@gmail.com>
+
 function [q, r, z, p] = cod (a, varargin)
 
   if (nargin < 1 || nargin > 2 || nargout > 4 || ! ismatrix (a))
