@@ -1,19 +1,18 @@
 ## Copyright (C) 2000, 2011 P.R. Nienhuis <prnienhuis@users.sf.net>
 ## Copyright (C) 2001 Paul Kienzle <pkienzle@users.sf.net>
 ##
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This program is distributed in the hope that it will be useful, but
-## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
 ##
-## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{B} =} funm (@var{A}, @var{F})
@@ -49,17 +48,6 @@
 ## @seealso{thfm, expm, logm, sqrtm}
 ## @end deftypefn
 
-## Author: P.R. Nienhuis <prnienhuis@users.sf.net> (somewhere in 2000)
-## Additions by P. Kienzle, .........
-## 2001-03-01 Paul Kienzle
-##            * Many code improvements
-## 2011-03-27 Philip Nienhuis
-##            * Function handles
-##            * Texinfo header
-##            * Fallback to thfm for trig & hyperb funcs to avoid diagonalization
-## 2011-07-29 Philip Nienhuis
-##            * Layout, cleanup (tabs, alignment, ...)
-
 function B = funm (A, name)
 
   persistent thfuncs  = {"cos",   "sin",   "tan",   "sec",   "csc",   "cot",   ...
